componenttools.sum_prolated_duration_of_components
==================================================

.. autofunction:: abjad.tools.componenttools.sum_prolated_duration_of_components.sum_prolated_duration_of_components
